import os

def get_relative_path(root_path, file_path):
        root_array = os.path.normpath(root_path).split(os.sep)
        file_array = os.path.normpath(file_path).split(os.sep)
        relative_array = [p for p in file_array if p not in root_array]
        relative_path = os.path.join(*relative_array)
        return relative_path



"""pycodya.

Usage:
  pycodya run <actions>  

Options:
  -h --help     Show this screen.
  --version     Show version.
  actions       alltests: test everything

"""

from docopt import docopt
from pycodya.run_tests import run_tests


def main():
    arguments = docopt(__doc__, version="0.1.1")
    print(arguments)

    if arguments['<actions>'] == 'alltests':
        run_tests()


if __name__ == '__main__':
    main()
    




import os

config = None
if os.path.exists('pycodya_config'):
    import pycodya_config as config


# Provide the autotest paths
DIR_GENERATED_TESTS= '.pycodya_tests' if not config else config.DIR_GENERATED_TESTS

# Provide the variable test
PYCODYA_VAR_NAME = 'CodyaTest' if not config else config.PYCODYA_VAR_NAME
